audformat.testing
=================

.. automodule:: audformat.testing

:mod:`audformat.testing` provides the possibility to create small
and well defined :class:`audformat.Database` objects
that are of interest for creating unit tests.

In order to use it you first have to import it explicitly:

.. code-block:: python

    import audformat.testing


create_db
---------

.. autofunction:: create_db

add_table
---------

.. autofunction:: add_table

create_audio_files
------------------

.. autofunction:: create_audio_files
